==> eiffelstudio-18.07.10.1981.tar: F_code/C15/xm710.c <==
/*
 * Code for class XM_XPATH_NON_EMPTY_NODE_ITERATOR
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "xm710.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {XM_XPATH_NON_EMPTY_NODE_ITERATOR}.make */
void F1573_13468 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_INTEGER_32 arg3)
{
	GTCX
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,arg2);
	RTLIU(3);
	
	RTGC;
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) arg1;
	RTAR(Current, arg2);
	*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) arg2;
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_4_1_0_1_) = (EIF_INTEGER_32) arg3;
	RTLE;
}

/* {XM_XPATH_NON_EMPTY_NODE_ITERATOR}.item */
EIF_REFERENCE F1573_13469 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,Result);
	RTLIU(3);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	Result = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R10486[Dtype(tr1)-1559])(RTCW(tr1));
	RTLE;
	return Result;
}

/* {XM_XPATH_NON_EMPTY_NODE_ITERATOR}.after */
EIF_BOOLEAN F1573_13470 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	Result = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R10493[Dtype(tr1)-1559])(RTCW(tr1));
	RTLE;
	return Result;
}

/* {XM_XPATH_NON_EMPTY_NODE_ITERATOR}.is_node_iterator */
EIF_BOOLEAN F1573_13471 (EIF_REFERENCE Current)
{
	GTCX
	
	
	return (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
}

/* {XM_XPATH_NON_EMPTY_NODE_ITERATOR}.start */
void F1573_13472 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_REFERENCE tr4 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(7);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,loc2);
	RTLR(3,loc1);
	RTLR(4,tr2);
	RTLR(5,tr3);
	RTLR(6,tr4);
	RTLIU(7);
	
	RTGC;
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_4_1_0_0_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	(FUNCTION_CAST(void, (EIF_REFERENCE)) R10506[Dtype(tr1)-1558])(RTCW(tr1));
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	tr1 = *(EIF_REFERENCE *)(RTCW(tr1) + O10488[Dtype(tr1)-1558]);
	loc2 = tr1;
	if (EIF_TEST(loc2)) {
		F1559_13318(Current, loc2);
	} else {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
		tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R10493[Dtype(tr1)-1559])(RTCW(tr1));
		if (tb1) {
			tr1 = RTLNS(eif_new_type(1631, 0x00).id, 1631, _OBJSIZ_5_0_0_2_0_0_0_0_);
			tr2 = RTOSCF(8222,F1128_8222,(Current));
			tr3 = RTMS_EX_H("An empty sequence is not allowed as the ",40,778916128);
			tr4 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
			tr4 = F1146_8562(RTCW(tr4));
			tr2 = F1113_8059(RTCW(tr2), tr3, tr4);
			tr3 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
			tr3 = *(EIF_REFERENCE *)(RTCW(tr3) + _REFACS_1_);
			tr4 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
			tr4 = *(EIF_REFERENCE *)(RTCW(tr4) + _REFACS_2_);
			F1632_14218(RTCW(tr1), tr2, tr3, tr4, ((EIF_INTEGER_32) 2L));
			loc1 = (EIF_REFERENCE) tr1;
			F1559_13318(Current, loc1);
		}
	}
	RTLE;
}

/* {XM_XPATH_NON_EMPTY_NODE_ITERATOR}.forth */
void F1573_13473 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_4_1_0_0_))++;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	(FUNCTION_CAST(void, (EIF_REFERENCE)) R10507[Dtype(tr1)-1559])(RTCW(tr1));
	RTLE;
}

/* {XM_XPATH_NON_EMPTY_NODE_ITERATOR}.as_node_iterator */
EIF_REFERENCE F1573_13474 (EIF_REFERENCE Current)
{
	GTCX
	
	
	return (EIF_REFERENCE) Current;
}

/* {XM_XPATH_NON_EMPTY_NODE_ITERATOR}.another */
EIF_REFERENCE F1573_13475 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,tr3);
	RTLR(4,Result);
	RTLIU(5);
	
	RTGC;
	tr1 = RTLNSMART(Dftype(Current));
	tr2 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	tr2 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R10513[Dtype(tr2)-1559])(RTCW(tr2));
	tr3 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_4_1_0_1_);
	F1573_13468(RTCW(tr1), tr2, tr3, ti4_1);
	Result = (EIF_REFERENCE) tr1;
	RTLE;
	return Result;
}

/* {XM_XPATH_NON_EMPTY_NODE_ITERATOR}.base_iterator */
EIF_REFERENCE F1573_13476 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_2_);
}


/* {XM_XPATH_NON_EMPTY_NODE_ITERATOR}.role_locator */
EIF_REFERENCE F1573_13478 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_3_);
}


void EIF_Minit710 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.11.10.2592.tar: F_code/C15/xm710.c <==
/*
 * Code for class XM_XPATH_NON_EMPTY_ITERATOR
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "xm710.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {XM_XPATH_NON_EMPTY_ITERATOR}.make */
void F1574_13499 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_INTEGER_32 arg3)
{
	GTCX
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,arg2);
	RTLIU(3);
	
	RTGC;
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) arg1;
	RTAR(Current, arg2);
	*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) arg2;
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_4_1_0_1_) = (EIF_INTEGER_32) arg3;
	RTLE;
}

/* {XM_XPATH_NON_EMPTY_ITERATOR}.item */
EIF_REFERENCE F1574_13500 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,Result);
	RTLIU(3);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	Result = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R10516[Dtype(tr1)-1561])(RTCW(tr1));
	RTLE;
	return Result;
}

/* {XM_XPATH_NON_EMPTY_ITERATOR}.after */
EIF_BOOLEAN F1574_13501 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	Result = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R10523[Dtype(tr1)-1561])(RTCW(tr1));
	RTLE;
	return Result;
}

/* {XM_XPATH_NON_EMPTY_ITERATOR}.start */
void F1574_13502 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_REFERENCE tr4 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(7);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,loc2);
	RTLR(3,loc1);
	RTLR(4,tr2);
	RTLR(5,tr3);
	RTLR(6,tr4);
	RTLIU(7);
	
	RTGC;
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_4_1_0_0_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	(FUNCTION_CAST(void, (EIF_REFERENCE)) R10536[Dtype(tr1)-1560])(RTCW(tr1));
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	tr1 = *(EIF_REFERENCE *)(RTCW(tr1) + O10518[Dtype(tr1)-1560]);
	loc2 = tr1;
	if (EIF_TEST(loc2)) {
		F1561_13358(Current, loc2);
	} else {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
		tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R10523[Dtype(tr1)-1561])(RTCW(tr1));
		if (tb1) {
			tr1 = RTLNS(eif_new_type(1633, 0x00).id, 1633, _OBJSIZ_5_0_0_2_0_0_0_0_);
			tr2 = RTOSCF(8261,F1130_8261,(Current));
			tr3 = RTMS_EX_H("An empty sequence is not allowed as the ",40,778916128);
			tr4 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
			tr4 = F1148_8601(RTCW(tr4));
			tr2 = F1115_8098(RTCW(tr2), tr3, tr4);
			tr3 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
			tr3 = *(EIF_REFERENCE *)(RTCW(tr3) + _REFACS_1_);
			tr4 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
			tr4 = *(EIF_REFERENCE *)(RTCW(tr4) + _REFACS_2_);
			F1634_14258(RTCW(tr1), tr2, tr3, tr4, ((EIF_INTEGER_32) 2L));
			loc1 = (EIF_REFERENCE) tr1;
			F1561_13358(Current, loc1);
		}
	}
	RTLE;
}

/* {XM_XPATH_NON_EMPTY_ITERATOR}.forth */
void F1574_13503 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_4_1_0_0_))++;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	(FUNCTION_CAST(void, (EIF_REFERENCE)) R10537[Dtype(tr1)-1561])(RTCW(tr1));
	RTLE;
}

/* {XM_XPATH_NON_EMPTY_ITERATOR}.another */
EIF_REFERENCE F1574_13504 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,tr3);
	RTLR(4,Result);
	RTLIU(5);
	
	RTGC;
	tr1 = RTLNSMART(Dftype(Current));
	tr2 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	tr2 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R10543[Dtype(tr2)-1561])(RTCW(tr2));
	tr3 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_4_1_0_1_);
	F1574_13499(RTCW(tr1), tr2, tr3, ti4_1);
	Result = (EIF_REFERENCE) tr1;
	RTLE;
	return Result;
}

/* {XM_XPATH_NON_EMPTY_ITERATOR}.base_iterator */
EIF_REFERENCE F1574_13505 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_2_);
}


/* {XM_XPATH_NON_EMPTY_ITERATOR}.role_locator */
EIF_REFERENCE F1574_13507 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_3_);
}


void EIF_Minit710 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
